summaryrefslogtreecommitdiff
path: root/lib/regex.c
diff options
context:
space:
mode:
authorBruno Haible <bruno@clisp.org>2005-03-15 12:00:04 +0000
committerBruno Haible <bruno@clisp.org>2005-03-15 12:00:04 +0000
commit624d27350d087d927c960675738856fe85c62efc (patch)
tree4d4d7beeecd56f9f137c3fc5d5ec4ae72027444a /lib/regex.c
parente04879ec01e63d163237521896132f1c1ca57ba0 (diff)
downloadgnulib-624d27350d087d927c960675738856fe85c62efc.tar.gz
Rename local variable 'not'. Needed when CC=g++.
Diffstat (limited to 'lib/regex.c')
-rw-r--r--lib/regex.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/regex.c b/lib/regex.c
index d3840704a0..904b481a34 100644
--- a/lib/regex.c
+++ b/lib/regex.c
@@ -6277,9 +6277,9 @@ byte_re_match_2_internal (struct re_pattern_buffer *bufp,
uint32_t nrules;
# endif /* _LIBC */
#endif /* WCHAR */
- boolean not = (re_opcode_t) *(p - 1) == charset_not;
+ boolean negate = (re_opcode_t) *(p - 1) == charset_not;
- DEBUG_PRINT2 ("EXECUTING charset%s.\n", not ? "_not" : "");
+ DEBUG_PRINT2 ("EXECUTING charset%s.\n", negate ? "_not" : "");
PREFETCH ();
c = TRANSLATE (*d); /* The character to match. */
#ifdef WCHAR
@@ -6612,20 +6612,20 @@ byte_re_match_2_internal (struct re_pattern_buffer *bufp,
if (c == *workp)
goto char_set_matched;
- not = !not;
+ negate = !negate;
char_set_matched:
- if (not) goto fail;
+ if (negate) goto fail;
#else
/* Cast to `unsigned' instead of `unsigned char' in case the
bit list is a full 32 bytes long. */
if (c < (unsigned) (*p * BYTEWIDTH)
&& p[1 + c / BYTEWIDTH] & (1 << (c % BYTEWIDTH)))
- not = !not;
+ negate = !negate;
p += 1 + *p;
- if (!not) goto fail;
+ if (!negate) goto fail;
#undef WORK_BUFFER_SIZE
#endif /* WCHAR */
SET_REGS_MATCHED ();
@@ -7125,15 +7125,15 @@ byte_re_match_2_internal (struct re_pattern_buffer *bufp,
else if ((re_opcode_t) p1[3] == charset
|| (re_opcode_t) p1[3] == charset_not)
{
- int not = (re_opcode_t) p1[3] == charset_not;
+ int negate = (re_opcode_t) p1[3] == charset_not;
if (c < (unsigned) (p1[4] * BYTEWIDTH)
&& p1[5 + c / BYTEWIDTH] & (1 << (c % BYTEWIDTH)))
- not = !not;
+ negate = !negate;
- /* `not' is equal to 1 if c would match, which means
+ /* `negate' is equal to 1 if c would match, which means
that we can't change to pop_failure_jump. */
- if (!not)
+ if (!negate)
{
p[-3] = (unsigned char) pop_failure_jump;
DEBUG_PRINT1 (" No match => pop_failure_jump.\n");